OrderConfiguration

Enum OrderConfiguration 

pub enum OrderConfiguration {
    MarketIoc {
        market_market_ioc: MarketIoc,
    },
    LimitGtc {
        limit_limit_gtc: LimitGtc,
    },
    LimitGtd {
        limit_limit_gtd: LimitGtd,
    },
    LimitFok {
        limit_limit_fok: LimitFok,
    },
    StopLimitGtc {
        stop_limit_stop_limit_gtc: StopLimitGtc,
    },
    StopLimitGtd {
        stop_limit_stop_limit_gtd: StopLimitGtd,
    },
}
Order configuration.

Variants



MarketIoc

Market order (immediate-or-cancel).

Fields

market_market_ioc: MarketIoc

Market IOC configuration.



LimitGtc

Limit order (good-til-cancelled).

Fields

limit_limit_gtc: LimitGtc

Limit GTC configuration.



LimitGtd

Limit order (good-til-date).

Fields

limit_limit_gtd: LimitGtd

Limit GTD configuration.



LimitFok

Limit order (fill-or-kill).

Fields

limit_limit_fok: LimitFok

Limit FOK configuration.



StopLimitGtc

Stop-limit order (good-til-cancelled).

Fields

stop_limit_stop_limit_gtc: StopLimitGtc

Stop-limit GTC configuration.



StopLimitGtd

Stop-limit order (good-til-date).

Fields

stop_limit_stop_limit_gtd: StopLimitGtd

Stop-limit GTD configuration.

Implementations

Source

impl OrderConfiguration

pub fn market_buy_quote(quote_size: impl Into<String>) -> Self

Create a market buy order by quote size (e.g., $100 of BTC).

pub fn market_buy_base(base_size: impl Into<String>) -> Self

Create a market buy order by base size (e.g., 0.001 BTC).

pub fn market_sell(base_size: impl Into<String>) -> Self

Create a market sell order by base size.

pub fn limit_gtc( base_size: impl Into<String>, limit_price: impl Into<String>, post_only: bool, ) -> Self

Create a limit GTC order.

pub fn limit_gtd( base_size: impl Into<String>, limit_price: impl Into<String>, end_time: impl Into<String>, post_only: bool, ) -> Self

Create a limit GTD order.

pub fn limit_fok( base_size: impl Into<String>, limit_price: impl Into<String>, ) -> Self

Create a limit FOK order.

pub fn stop_limit_gtc( base_size: impl Into<String>, limit_price: impl Into<String>, stop_price: impl Into<String>, stop_direction: StopDirection, ) -> Self

Create a stop-limit GTC order.

pub fn stop_limit_gtd( base_size: impl Into<String>, limit_price: impl Into<String>, stop_price: impl Into<String>, end_time: impl Into<String>, stop_direction: StopDirection, ) -> Self

Create a stop-limit GTD order.