pub struct RestClientBuilder { /* private fields */ }Expand description
Builder for constructing a RestClient.
Implementations
Sourceimpl RestClientBuilder
impl RestClientBuilder
Sourcepub fn credentials(self, credentials: Credentials) -> Self
pub fn credentials(self, credentials: Credentials) -> Self
Set the API credentials.
Required for authenticated endpoints. Public endpoints can be accessed without credentials.
Sourcepub fn sandbox(self, enabled: bool) -> Self
pub fn sandbox(self, enabled: bool) -> Self
Enable sandbox mode.
When enabled, requests are sent to the Coinbase sandbox environment.
Sourcepub fn timeout(self, timeout: Duration) -> Self
pub fn timeout(self, timeout: Duration) -> Self
Set the request timeout.
Default is 30 seconds.
Sourcepub fn rate_limiting(self, enabled: bool) -> Self
pub fn rate_limiting(self, enabled: bool) -> Self
Enable or disable rate limiting.
When enabled, the client will automatically throttle requests to avoid hitting Coinbase API rate limits.
Sourcepub fn build(self) -> Result<RestClient>
pub fn build(self) -> Result<RestClient>
Build the REST client.